Development
===========

Running from git
----------------

::

    git clone git://github.com/lmacken/pyrasite.git
    cd pyrasite
    python pyrasite/main.py

::

    git clone git://github.com/lmacken/pyrasite-gui.git
    cd pyrasite-gui
    python pyrasite_gui/gui.py

Git flow
--------

Use `git-flow <https://github.com/nvie/gitflow.git>`_.

Style
-----

 * `PEP8 <www.python.org/dev/peps/pep-0008>`_
